/*
 * Ambient - the ultimate desktop
 * ------------------------------
 * Copyright 2001-2005 by David Gerber <zapek@morphos.net>
 * All Rights Reserved
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 *
 * $Id: multimedia.c,v 1.7 2007/09/29 13:35:31 fab Exp $
 */

#include "ambient.h"

#if USE_MULTIMEDIA
#define USE_INLINE_STDARG

/* public */
#include <proto/multimedia.h>

/* private */
#include "multimedia.h"
#include "mui_func.h" /* for getv().. */


struct Library *MultimediaBase;
struct SignalSemaphore mmsem;


ULONG multimedia_init(void)
{
	InitSemaphore(&mmsem);
	
	return (TRUE);
}


void multimedia_cleanup(void)
{
	/* zZz */
}


ULONG multimedia_open(void)
{
	ULONG rc = FALSE;

	ObtainSemaphore(&mmsem);

	if (MultimediaBase)
	{
		rc = TRUE;
	}
	else
	{
		/*
		 *  [krashan] multimedia.class is now v52
		 */

		MultimediaBase = OpenLibrary("multimedia/multimedia.class", 52);

		if(MultimediaBase)
		{
			if (MultimediaBase->lib_Version > 52 ||	(MultimediaBase->lib_Version == 52 && MultimediaBase->lib_Revision >= 5))
			{
				rc = TRUE;
			}
			else
			{
				CloseLibrary(MultimediaBase);
				MultimediaBase = NULL;
			}
		}
	}
	
	ReleaseSemaphore(&mmsem);

	return (rc);
}


void multimedia_close(void)
{
	ObtainSemaphore(&mmsem);

	if (MultimediaBase)
	{
		CloseLibrary(MultimediaBase);
		MultimediaBase = NULL;
	}

	ReleaseSemaphore(&mmsem);
}


/* XXX: not used yet.. */
ULONG multimedia_findtype(STRPTR path)
{
	APTR obj;
	ULONG type = MULTIMEDIATYPE_NONE;

	THREAD;

	if (multimedia_open())
	{
		#if 1
		struct TagItem tags[4];

		tags[0].ti_Tag = MMA_StreamType;
		tags[0].ti_Data = (ULONG)"file.stream";
		tags[1].ti_Tag = MMA_StreamName;
		tags[1].ti_Data = (ULONG)path;
		tags[2].ti_Tag = MMA_Recognition;
		tags[2].ti_Data = MMREC_HEAVY; /* XXX: I should tune that.. not sure MMREC_HEAVY is right.. */
		tags[3].ti_Tag = TAG_DONE;

		if ((obj = MediaNewObjectTagList(tags)))
		#else
		if (obj = MediaNewObjectTags(MMA_StreamType, (ULONG)"file.stream",
									 MMA_StreamName, (ULONG)path,
									 MMA_Recognition, MMREC_HEAVY,
		TAG_DONE))
		#endif
		{
			switch (getv(obj, MMA_MediaType))
			{
				case MMT_SOUND:
					type = MULTIMEDIATYPE_SOUND;
					break;
			}
			DisposeObject(obj);
		}
	}
	return (type);
}


ULONG multimedia_find(STRPTR path)
{
	ULONG rc = FALSE;
	APTR obj;

	THREAD;

	if (multimedia_open())
	{
		#if 1
		struct TagItem tags[5];

		tags[0].ti_Tag = MMA_StreamType;
		tags[0].ti_Data = (ULONG)"file.stream";
		tags[1].ti_Tag = MMA_StreamName;
		tags[1].ti_Data = (ULONG)path;
		tags[2].ti_Tag = MMA_Recognition;
		tags[2].ti_Data = MMREC_HEAVY;
		tags[3].ti_Tag = MMA_MediaType;
		tags[3].ti_Data = MMT_SOUND;
		tags[4].ti_Tag = TAG_DONE;

		if ((obj = MediaNewObjectTagList(tags)))
		#else
		if (obj = MediaNewObjectTags(MMA_StreamType, (ULONG)"file.stream",
									 MMA_StreamName, (ULONG)path,
									 MMA_Recognition, MMREC_HEAVY,
									 MMA_MediaType, MMT_SOUND, /* XXX: for now.. next I should support pictures, videos, etc.. */
		TAG_DONE))
		#endif
		{
			rc = TRUE;

			DisposeObject(obj);
		}
		multimedia_close();
	}
	return (rc);
}

#endif /* USE_MULTIMEDIA */
